@@ -144,16 +144,25 @@ class GAV3Reader:
                         start_index=page_token,
                         date=date,
                     )
-                    if len(response.get("rows", [])) < 1:
+                    if not response:
+                        print(f"No response for view_id: {view_id}")
+                        break
+                    elif len(response.get("rows", [])) < 1:
                         print("No more data in response.")
                         break
                     page_token += response.get("itemsPerPage", 0)
 
-                    date_dataset.append(self._normalize_data(response))
+                    date_dataset.extend( self._normalize_data(response) )
 
                 # generator preserves memory, additional data provided
                 # to efficiently partition to s3
-                yield {"data": date_dataset[0], "date": date, "view_id": view_id}
+                # only yield if data is returned.
+                if date_dataset:
+                    # TODO: use self.tracking_object byte_size attrib 
+                    #       to determine whether or not to yield here
+                    yield {"data": date_dataset, "date": date, "view_id": view_id}
+                else:
+                    print("View ID had no data for given date, skipping.")
 
 
 class BaseGAV4Reader:
